@@ -5,7 +5,7 @@
  *
  * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
+ * published by the Free Software Foundation, either version 2 of
  * the License, or (at your option) any later version.
  * Seed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,7 +38,7 @@ extern JSObjectRef seed_obj_ref;
 
 extern JSContextGroupRef context_group;
 
-JSStringRef defaults_script;
+extern JSStringRef defaults_script;
 
 typedef struct _SeedScript
 {
