@@ -5,7 +5,7 @@
  *
  * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
+ * published by the Free Software Foundation, either version 2 of
  * the License, or (at your option) any later version.
  * Seed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -231,7 +231,7 @@ seed_gtype_builtin_get_property (GObject * object,
 
   seed_prepare_global_context (ctx);
 
-  seed_gvalue_from_seed_value (ctx, jsval, spec->value_type, value, 0);
+  seed_value_to_gvalue (ctx, jsval, spec->value_type, value, 0);
 
   g_free (name);
   JSGlobalContextRelease ((JSGlobalContextRef) ctx);
@@ -1031,10 +1031,12 @@ seed_define_gtype_functions (JSContextRef ctx)
 						 "GObject", "ObjectClass");
 
   proto = seed_struct_prototype (ctx, objectclass_info);
-
+/*
+  // paramspec is remove in newer versions of introspeciton - removing
+  // until we can work out how to replace this.
   paramspec_info = g_irepository_find_by_name (NULL, "GObject", "ParamSpec");
   proto = seed_struct_prototype (ctx, paramspec_info);
-
+*/
   seed_create_function (ctx, "get", &seed_param_getter_invoked, proto);
   seed_create_function (ctx, "set", &seed_param_setter_invoked, proto);
 }
