@@ -5,7 +5,7 @@
  *
  * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
+ * published by the Free Software Foundation, either version 2 of
  * the License, or (at your option) any later version.
  * Seed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -466,7 +466,7 @@ seed_gi_importer_do_namespace (JSContextRef ctx,
 
   jsextension = g_strdup_printf ("imports.extensions.%s", namespace);
   extension_script = JSStringCreateWithUTF8CString (jsextension);
-  JSEvaluateScript (ctx, extension_script, NULL, NULL, 0, NULL);
+  JSEvaluateScript (ctx, extension_script, NULL, NULL, 0, exception);
   JSStringRelease (extension_script);
   g_free (jsextension);
 
@@ -574,7 +574,8 @@ seed_importer_get_search_path (JSContextRef ctx, JSValueRef * exception)
 				    exception);
       entry = seed_value_to_string (ctx, entry_ref, exception);
 
-      path = g_slist_append (path, entry);
+      if (g_file_test (entry, G_FILE_TEST_EXISTS) == TRUE)
+        path = g_slist_append (path, entry);
     }
 
   return path;
