@@ -5,7 +5,7 @@
  *
  * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
+ * published by the Free Software Foundation, either version 2 of
  * the License, or (at your option) any later version.
  * Seed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -151,6 +151,7 @@ seed_release_arg (GITransfer transfer,
 	    case GI_TYPE_TAG_GTYPE:
 	    case GI_TYPE_TAG_FLOAT:
 	    case GI_TYPE_TAG_UINT8:
+            case GI_TYPE_TAG_UINT32:
 	      g_free (arg->v_pointer);
 	      break;
 	    case GI_TYPE_TAG_INTERFACE:
@@ -464,6 +465,22 @@ seed_gi_make_array (JSContextRef ctx,
 
 	g_base_info_unref (interface);
       }
+    case GI_TYPE_TAG_UINT32:
+      {
+        guint32 *uintresult;
+
+        uintresult = g_new0 (guint32, length + 1);
+
+        for (i = 0; i < length; i++)
+          {
+            elem = JSObjectGetPropertyAtIndex (ctx,
+                                               (JSObjectRef) array,
+                                               i, exception);
+	    uintresult[i] = seed_value_to_uint (ctx, elem, exception);
+          }
+        *array_p = uintresult;
+      }
+      break;
     default:
       seed_make_exception (ctx, exception, "ArgumentError",
 			   "Unhandled array element type");
@@ -857,10 +874,45 @@ seed_value_from_gi_argument (JSContextRef ctx,
     case GI_TYPE_TAG_ARRAY:
       {
 	GITypeInfo *param_type;
+        GIArrayType array_type;
 	JSValueRef ret;
 
 	if (arg->v_pointer == NULL)
 	  return JSValueMakeNull (ctx);
+
+        array_type = g_type_info_get_array_type (type_info);
+
+        if (array_type == GI_ARRAY_TYPE_PTR_ARRAY)
+          {
+            JSObjectRef ret_ptr_array;
+            GITypeInfo *array_type_info;
+            GPtrArray *ptr = arg->v_pointer;
+            GArgument larg;
+            int length = 0;
+            int i;
+
+            if (!ptr)
+              break;
+
+            length = ptr->len;
+            array_type_info = g_type_info_get_param_type (type_info, 0);
+            ret_ptr_array = JSObjectMakeArray (ctx, 0, NULL, exception);
+
+            for (i = 0; i < length; ++i) 
+              {
+                JSValueRef ival;
+
+                larg.v_pointer =  g_ptr_array_index(ptr, i);
+                ival = (JSValueRef) seed_value_from_gi_argument (ctx, &larg,
+                                                                 array_type_info, exception);
+                if (!ival)
+                  ival = JSValueMakeNull (ctx);
+
+                JSObjectSetPropertyAtIndex (ctx, ret_ptr_array, i, ival, NULL);
+              }
+            return ret_ptr_array;
+          }
+
 	if (!g_type_info_is_zero_terminated (type_info))
 	  break;
 
@@ -1029,6 +1081,12 @@ seed_value_from_gvalue (JSContextRef ctx,
       return seed_make_pointer (ctx, g_value_get_param (gval));
     }
 
+  if (g_type_is_a (G_VALUE_TYPE (gval), G_TYPE_STRV))
+    {
+      return seed_value_from_strv(ctx, g_value_get_boxed (gval), exception);
+    }
+
+
   if (g_type_is_a (G_VALUE_TYPE (gval), G_TYPE_ENUM) ||
       g_type_is_a (G_VALUE_TYPE (gval), G_TYPE_FLAGS))
     return seed_value_from_long (ctx, gval->data[0].v_long, exception);
@@ -2451,3 +2509,35 @@ out:
 		       "Unable to convert JavaScript value to time_t");
   return 0;
 }
+
+/**
+ * seed_value_from_strv:
+ * @ctx: A #SeedContext.
+ * @val: The #GStrv to wrap.
+ * @exception: A reference to a #SeedValue in which to store any exceptions.
+ *             Pass %NULL to ignore exceptions.
+ *
+ * Wraps @val in a #SeedValue.
+ *
+ * Return value: A #SeedValue which wraps @val, or %NULL if an exception
+ *               is raised during the conversion.
+ *
+ */
+JSValueRef
+seed_value_from_strv (JSContextRef ctx,
+		      GStrv * val, JSValueRef * exception)
+{
+      GArray *js_string_array = g_array_new (FALSE, FALSE, sizeof(gpointer));
+      for (; *val != NULL; val++)
+	{
+	  JSStringRef js_string = JSStringCreateWithUTF8CString((char*)*val);
+	  js_string_array = g_array_append_val(js_string_array, js_string);
+	}
+      JSValueRef res = JSObjectMakeArray (ctx,
+					  js_string_array->len,
+					  (JSValueRef*)js_string_array->data,
+					  exception);
+      g_array_free (js_string_array, FALSE);
+
+      return res;
+}
